==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/addressbook/language/th.php <==
<?php


$l['name'] = 'สมุดที่อยู่';
$l['description'] = 'ส่วนการจัดการผู้ติดต่อทั้งหมด.';
$l['allAddressbooks'] = 'สมุดที่อยู่ทั้งหมด';
$lang['common']['addressbookAlreadyExists'] = 'คุณพยายามสร้างสมุดที่อยู่ที่มีอยู่เดิมแล้ว';//The addressbook you are trying to create already exists;
$l['notIncluded'] = 'ห้ามทำการนำเข้า';
$l['comment'] = 'คำอธิบาย';
$l['bankNo'] = 'หมายเลขบัญชี'; //Bank number;
$l['vatNo'] = 'หมายเลขผู้เสียภาษี';
$l['contactsGroup'] = 'กลุ่ม';
$lang['link_type'][2]=$l['contact'] = 'ผู้ติดต่อ';
$lang['link_type'][3]=$l['company'] = 'หน่วยงาน';
$l['customers'] = 'ลูกค้า';
$l['suppliers'] = 'ผู้จัดหา';
$l['prospects'] = 'คุณสมบัติ';
$l['contacts'] = 'ผู้ติดต่อ';
$l['companies'] = 'หน่วยงาน';
$l['newContactAdded']='เพิ่มผู้ติดต่อใหม่';
$l['newContactFromSite']='ได้ทำการผู้ติดต่อใหมแล้ว.';
$l['clickHereToView']='คลิกเพื่อดูรายการผู้ติดต่อ';
$l['contactFromAddressbook']='ติดต่อจาก %s';
$l['companyFromAddressbook']='จากหน่วยงาน %s';
$l['defaultSalutation']='ถึง [Mr./Mrs.] {middle_name} {last_name}';

$l["selectMailingGroup"]='เลือกส่งเป็นกลุ่ม';
$l["cmdFormLabelAddressBooks"]= 'สมุดที่อยู่';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'ไฟล์ทั้งหมด';
$l["btnAddContact"]= 'เพิ่มข้อมูลผู้ติดต่อ'	;
$l["btnAddCompany"]= 'เพิ่มข้อมูลหน่วยงาน';
$l["btnManage"]= 'การจัดการ';
$l["btnDownload"]= 'ดาวน์โหลด ไฟล์';
$l["cmdFormSearchFirst"]= 'ค้นหา ใน= ';
$l["cmdFormSearchSecond"]= ' บน= ';
$l["cmdFormSearchThird"]= ' จาก= ';
$l["cmdFormSearchFourth"]= '(ใช้ \'%\'เป็นสัญลักษณ์แทน) ';//Use \'%\' as a wildcard;
$l["cmdFormLabelTitleInitials"]= 'คำนำหน้าชื่อ/ชื่อย่อ';
$l["cmdFormLabelSalutation"]= 'คำขึ้นต้น';
$l["cmdFormLabelComment"]= 'คำอธิบาย';
$l["cmdFormCompanyEmptyText"]= 'กรุณาเลือกหน่วยงาน';
$l["cmdFieldsetSelectAddressbook"]= 'เลือกสมุดข้อมูลผู้ติดต่อ';
$l["cmdFieldsetPersonalDetails"]= 'รายละเอียดส่วนบุคคล';
$l["cmdFieldsetAddress"]= 'ที่อยู่';
$l["cmdFieldsetContact"]= 'รายละเอียด';
$l["cmdFieldsetWork"]= 'ที่ทำงาน';
$l["cmdPanelContact"]= 'รายละเอียด';
$l["cmdPanelComments"]= 'คำอธิบาย';
$l["cmdContactDialog"]= 'แก้ไขข้อมูลผู้ติดต่อ';
$l["contact"]= 'ผู้ติดต่อ';
$l["cmdSalutation"]= 'ถึง';
$l["cmdMadam"]= 'คุณผู้หญิง';
$l["cmdSir"]= 'ท่าน';
$l["btnDownloadTextDocument"]= 'ดาวน์โหลดเอกสาร';
$l["cmdContactDetailsFor"]= 'รายละเอียดส่วนบุคคลจาก';
$l["cmdLInkFieldset"]= 'เชื่อมโยง';
$l["company"]= 'หน่วยงาน';
$l["cmdCompanyDetailsFor"]= 'รายละเอียกจาก';
$l["cmdPanelCompany"]= 'รายละเอียดหน่วยงาน';
$l["cmdFormLabelBankNo"]= 'หมายเลขธนาคาร';//Bank number;
$l["cmdFormLabelVatNo"]= 'หมายเลขผู้เสียภาษี';
$l["cmdFieldsetCompanyDetails"]= 'รายละเอียดเพิ่มเติม';
$l["cmdFieldsetVisitAddress"]= 'ที่อยู่ปัจจุบัน';
$l["cmdFieldsetPostAddress"]= 'ที่อยู่ที่สามารถติดต่อได้';
$l["cmdCompanyDialog"]= 'แก้ไขข้อมูลหน่วยงาน';
$l["cmdPanelEmployees"]= 'พนักงาน';
$l["cmdPanelEmployee"]= 'พนักงาน';
$l["cmdAllEmployeesForThisCompany"]= 'พนักงานทั้งหมดในหน่วยงานนี้';
$l["cmdFieldsetVisitAddress"]= 'ที่อยู่ปัจจุบัน';
$l["cmdFieldsetPostAddress"]= 'ที่อยู่ที่สามารถติดต่อได้';
$l["cmdManageDialog"]= 'การจัดการ';
$l["cmdAddAddressBook"]= 'เพิ่มข้อมูลสมุดผู้ติดต่อ';
$l["cmdDeleteAddressbook"]= 'ลบข้อมูลสมุดผู้ติดต่อ';
$l["cmdOwner"]= 'เจ้าของ';
$l["cmdPanelAddressbook"]= 'สมุดผู้ติดต่อ';
$l["cmdPanelProperties"]= 'คุณสมบัติ';
$l["cmdContactDialog"]= 'แก้ไขผู้ติดต่อ';
$l["cmdFormLabelFileType"]= 'ประเภทไฟล์';
$l["cmdFormLabelFile"]= 'ไฟล์';	;
$l["cmdFormLabelValueSeperated"]= 'คั่นค่าด้วย';//Values separated by;
$l["cmdFormLabelValueIncluded"]= 'ครอบคุมค่าด้วย';//Values encapsulated by;
$l["cmdFormLabelLinesEnded"]= 'กำหนดจากเส้นสิ้นสุด';//Lines ended by;
$l["cmdUpload"]= 'อัพโหลด';
$l["cmdImport"]= 'นำเข้า';
$l["cmdExport"]= 'ส่งออก';
$l["cmdType"]= 'ประเภท';
$l["contacts"]= 'ผู้ติดต่อ';
$l["companies"]= 'หน่วยงาน';
$l["users"]= 'ผู้ใช้งาน';
$l["strSelectContact"]= 'เลือกผู้ติดต่อ';
$l["strSelectCompany"]= 'เลือกหน่วยงาน';
$l["noAddressbooks"]= 'ไม่มีสมุดที่อยู่';
$l["moveAll"]= 'ข้อมูลหน่วยงานและพนักงานจะถูกย้ายไปยังสมุดที่อยู่ใหม่ ต้องการทำรายการข้างต้นหรือไม่?';
$l["addressbook"]= 'สมุดที่อยู่';
$l["addressbooks"]= 'สมุดที่อยู่';
$l["sendMailing"]='ส่งจดหมายข่าว';
$l["importSuccess"]='การนำเข้าข้อมูลสำเร็จ';
$l["searchOnSender"]='ค้นหาในสมุดที่อยู่';
$l["confirmCreate"]='ไม่มีรายการผู้ติดต่อใหม่. คุณต้องการเพิ่มผู้ติดต่อใหม่?';
$l["matchFields"]='Match the fields';
$l["advancedSearch"]='ค้นหาแบบละเอียด';
$l["defaultAddressFormat"]='ค่าเริ่มต้นรูปแบบที่อยู่';
$l["defaultSalutation"]='ค่าเริ่มต้นข้อความแสดงความเคารพ';
$l["explanationVariables"]='ข้อความอธิบายค่าตัวแปล ค่าเริ่มต้นข้อความแสดงความเคารพ';
$l["explanationSex"]='Male and female form of salutation';
$l["newSearch"]='ค้นหาใหม่';
$l["executeQuery"]='ดำเนินการค้นหา';
$l["savedQueries"]='บันทึกการค้นหา';
$l["selectField"]= 'Select field';
$l["searchQueryName"]='ชื่อคำค้นหา';
$l["enterSearchQueryName"]='ระบุชื่อที่ต้องการค้นหา:';
$l["photo"]= 'ภาพถ่าย';
$l["deleteImage"]='ลบรูปภาพ';
$l["addAllSearchResults"]='เพิ่มผลการค้นหาทั้งหมด';
$l["confirmAddAllSearchResults"]='คุณแน่ใจหรือว่าต้องการเพิ่มผลจากการค้นหาทั้งหมดลงยังชุดรายการที่อยู่ ?';
$l["moveEmployees"]='ย้ายพนักงาน';
$l["id"]='ID';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/addressbook/language/th.php <==
<?php


$l['name'] = 'สมุดที่อยู่';
$l['description'] = 'ส่วนการจัดการผู้ติดต่อทั้งหมด.';
$l['allAddressbooks'] = 'สมุดที่อยู่ทั้งหมด';
$lang['common']['addressbookAlreadyExists'] = 'คุณพยายามสร้างสมุดที่อยู่ที่มีอยู่เดิมแล้ว';//The addressbook you are trying to create already exists;
$l['notIncluded'] = 'ห้ามทำการนำเข้า';
$l['comment'] = 'คำอธิบาย';
$l['bankNo'] = 'หมายเลขบัญชี'; //Bank number;
$l['vatNo'] = 'หมายเลขผู้เสียภาษี';
$l['contactsGroup'] = 'กลุ่ม';
$lang['link_type'][2]=$lang['link_type'][3]=$l['customers'] = 'ลูกค้า';
$l['suppliers'] = 'ผู้จัดหา';
$l['prospects'] = 'คุณสมบัติ';
$l['newContactAdded']='เพิ่มผู้ติดต่อใหม่';
$l['newContactFromSite']='ได้ทำการผู้ติดต่อใหมแล้ว.';
$l['clickHereToView']='คลิกเพื่อดูรายการผู้ติดต่อ';
$l['contactFromAddressbook']='ติดต่อจาก %s';
$l['companyFromAddressbook']='จากหน่วยงาน %s';
$l["selectMailingGroup"]='เลือกส่งเป็นกลุ่ม';
$l["cmdFormLabelAddressBooks"]= 'สมุดที่อยู่';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'ไฟล์ทั้งหมด';
$l["btnAddContact"]= 'เพิ่มข้อมูลผู้ติดต่อ'	;
$l["btnAddCompany"]= 'เพิ่มข้อมูลหน่วยงาน';
$l["btnManage"]= 'การจัดการ';
$l["btnDownload"]= 'ดาวน์โหลด ไฟล์';
$l["cmdFormSearchFirst"]= 'ค้นหา ใน= ';
$l["cmdFormSearchSecond"]= ' บน= ';
$l["cmdFormSearchThird"]= ' จาก= ';
$l["cmdFormSearchFourth"]= '(ใช้ \'%\'เป็นสัญลักษณ์แทน) ';//Use \'%\' as a wildcard;
$l["cmdFormLabelTitleInitials"]= 'คำนำหน้าชื่อ/ชื่อย่อ';
$l["cmdFormLabelSalutation"]= 'คำขึ้นต้น';
$l["cmdFormLabelComment"]= 'คำอธิบาย';
$l["cmdFormCompanyEmptyText"]= 'กรุณาเลือกหน่วยงาน';
$l["cmdFieldsetSelectAddressbook"]= 'เลือกสมุดข้อมูลผู้ติดต่อ';
$l["cmdFieldsetPersonalDetails"]= 'รายละเอียดส่วนบุคคล';
$l["cmdFieldsetAddress"]= 'ที่อยู่';
$l["cmdFieldsetContact"]= 'รายละเอียด';
$l["cmdFieldsetWork"]= 'ที่ทำงาน';
$l["cmdPanelContact"]= 'รายละเอียด';
$l["cmdPanelComments"]= 'คำอธิบาย';
$l["contact"]= 'ผู้ติดต่อ';
$l["cmdSalutation"]= 'ถึง';
$l["cmdMadam"]= 'คุณผู้หญิง';
$l["cmdSir"]= 'ท่าน';
$l["btnDownloadTextDocument"]= 'ดาวน์โหลดเอกสาร';
$l["cmdContactDetailsFor"]= 'รายละเอียดส่วนบุคคลจาก';
$l["cmdLInkFieldset"]= 'เชื่อมโยง';
$l["company"]= 'หน่วยงาน';
$l["cmdCompanyDetailsFor"]= 'รายละเอียกจาก';
$l["cmdPanelCompany"]= 'รายละเอียดหน่วยงาน';
$l["cmdFormLabelBankNo"]= 'หมายเลขธนาคาร';//Bank number;
$l["cmdFormLabelVatNo"]= 'หมายเลขผู้เสียภาษี';
$l["cmdFieldsetCompanyDetails"]= 'รายละเอียดเพิ่มเติม';
$l["cmdCompanyDialog"]= 'แก้ไขข้อมูลหน่วยงาน';
$l["cmdPanelEmployees"]= 'พนักงาน';
$l["cmdPanelEmployee"]= 'พนักงาน';
$l["cmdAllEmployeesForThisCompany"]= 'พนักงานทั้งหมดในหน่วยงานนี้';
$l["cmdFieldsetVisitAddress"]= 'ที่อยู่ปัจจุบัน';
$l["cmdFieldsetPostAddress"]= 'ที่อยู่ที่สามารถติดต่อได้';
$l["cmdManageDialog"]= 'การจัดการ';
$l["cmdAddAddressBook"]= 'เพิ่มข้อมูลสมุดผู้ติดต่อ';
$l["cmdDeleteAddressbook"]= 'ลบข้อมูลสมุดผู้ติดต่อ';
$l["cmdOwner"]= 'เจ้าของ';
$l["cmdPanelAddressbook"]= 'สมุดผู้ติดต่อ';
$l["cmdPanelProperties"]= 'คุณสมบัติ';
$l["cmdContactDialog"]= 'แก้ไขผู้ติดต่อ';
$l["cmdFormLabelFileType"]= 'ประเภทไฟล์';
$l["cmdFormLabelFile"]= 'ไฟล์';	;
$l["cmdFormLabelValueSeperated"]= 'คั่นค่าด้วย';//Values separated by;
$l["cmdFormLabelValueIncluded"]= 'ครอบคุมค่าด้วย';//Values encapsulated by;
$l["cmdFormLabelLinesEnded"]= 'กำหนดจากเส้นสิ้นสุด';//Lines ended by;
$l["cmdUpload"]= 'อัพโหลด';
$l["cmdImport"]= 'นำเข้า';
$l["cmdExport"]= 'ส่งออก';
$l["cmdType"]= 'ประเภท';
$l["contacts"]= 'ผู้ติดต่อ';
$l["companies"]= 'หน่วยงาน';
$l["users"]= 'ผู้ใช้งาน';
$l["strSelectContact"]= 'เลือกผู้ติดต่อ';
$l["strSelectCompany"]= 'เลือกหน่วยงาน';
$l["noAddressbooks"]= 'ไม่มีสมุดที่อยู่';
$l["moveAll"]= 'ข้อมูลหน่วยงานและพนักงานจะถูกย้ายไปยังสมุดที่อยู่ใหม่ ต้องการทำรายการข้างต้นหรือไม่?';
$l["addressbook"]= 'สมุดที่อยู่';
$l["addressbooks"]= 'สมุดที่อยู่';
$l["sendMailing"]='ส่งจดหมายข่าว';
$l["importSuccess"]='การนำเข้าข้อมูลสำเร็จ';
$l["searchOnSender"]='ค้นหาในสมุดที่อยู่';
$l["confirmCreate"]='ไม่มีรายการผู้ติดต่อใหม่. คุณต้องการเพิ่มผู้ติดต่อใหม่?';
$l["matchFields"]='Match the fields';
$l["advancedSearch"]='ค้นหาแบบละเอียด';
$l["defaultAddressFormat"]='ค่าเริ่มต้นรูปแบบที่อยู่';
$l["defaultSalutation"]='ค่าเริ่มต้นข้อความแสดงความเคารพ';
$l["explanationVariables"]='ข้อความอธิบายค่าตัวแปล ค่าเริ่มต้นข้อความแสดงความเคารพ';
$l["explanationSex"]='Male and female form of salutation';
$l["newSearch"]='ค้นหาใหม่';
$l["executeQuery"]='ดำเนินการค้นหา';
$l["savedQueries"]='บันทึกการค้นหา';
$l["selectField"]= 'Select field';
$l["searchQueryName"]='ชื่อคำค้นหา';
$l["enterSearchQueryName"]='ระบุชื่อที่ต้องการค้นหา:';
$l["photo"]= 'ภาพถ่าย';
$l["deleteImage"]='ลบรูปภาพ';
$l["addAllSearchResults"]='เพิ่มผลการค้นหาทั้งหมด';
$l["confirmAddAllSearchResults"]='คุณแน่ใจหรือว่าต้องการเพิ่มผลจากการค้นหาทั้งหมดลงยังชุดรายการที่อยู่ ?';
$l["moveEmployees"]='ย้ายพนักงาน';
$l["id"]='ID';
